@@ -59,7 +59,9 @@ int idmap_verbosity = 0;
 static struct mapping_plugin **nfs4_plugins = NULL;
 static struct mapping_plugin **gss_plugins = NULL;
 
-#define PLUGIN_PREFIX "libnfsidmap_"
+#ifndef PATH_PLUGINS
+#define PATH_PLUGINS "/usr/lib/libnfsidmap"
+#endif
 #define PLUGIN_INIT_FUNC "libnfsidmap_plugin_init"
 
 
@@ -67,6 +69,10 @@ static struct mapping_plugin **gss_plugins = NULL;
 #define PATH_IDMAPDCONF "/etc/idmapd.conf"
 #endif
 
+#ifndef IDMAPD_DEFAULT_DOMAIN
+#define IDMAPD_DEFAULT_DOMAIN "localdomain"
+#endif
+
 /* Default logging fuction */
 static void default_logger(const char *fmt, ...)
 {
@@ -78,6 +84,14 @@ static void default_logger(const char *fmt, ...)
 }
 nfs4_idmap_log_function_t idmap_log_func = default_logger;
 
+static char * toupper_str(char *s)
+{
+	int i;
+	for (i=0; i < strlen(s); i++)
+		s[i] = toupper(s[i]);
+	return s;
+}
+
 static int domain_from_dns(char **domain)
 {
 	struct hostent *he;
@@ -101,7 +115,7 @@ static int load_translation_plugin(char *method, struct mapping_plugin *plgn)
 	char plgname[128];
 	int ret = 0;
 
-	snprintf(plgname, sizeof(plgname), "%s%s.so", PLUGIN_PREFIX, method);
+	snprintf(plgname, sizeof(plgname), "%s/%s.so", PATH_PLUGINS, method);
 
 	dl = dlopen(plgname, RTLD_NOW | RTLD_LOCAL);
 	if (dl == NULL) {
@@ -212,16 +226,41 @@ int nfs4_init_name_mapping(char *conffile)
 		dflt = 1;
 		ret = domain_from_dns(&default_domain);
 		if (ret) {
-			IDMAP_LOG(0, ("libnfsidmap: Unable to determine "
-				  "a default nfsv4 domain; consider "
-				  "specifying one in idmapd.conf\n"));
-			return -ENOENT;
+			IDMAP_LOG(1, ("libnfsidmap: Unable to determine "
+				  "the NFSv4 domain; Using '%s' as the NFSv4 domain "
+				  "which means UIDs will be mapped to the 'Nobody-User' "
+				  "user defined in %s\n", 
+				  IDMAPD_DEFAULT_DOMAIN, PATH_IDMAPDCONF));
+			default_domain = IDMAPD_DEFAULT_DOMAIN;
 		}
 	}
 	IDMAP_LOG(1, ("libnfsidmap: using%s domain: %s\n",
 		(dflt ? " (default)" : ""), default_domain));
 
+	/* Get list of "local equivalent" realms.  Meaning the list of realms
+	 * where john@REALM.A is considered the same user as john@REALM.B
+	 * If not specified, default to upper-case of local domain name */
 	local_realms = conf_get_list("General", "Local-Realms");
+	if (local_realms == NULL) {
+		struct conf_list_node *node;
+
+		local_realms = malloc(sizeof *local_realms);
+		if (local_realms == NULL)
+			return -ENOMEM;
+		local_realms->cnt = 0;
+		TAILQ_INIT(&local_realms->fields);
+
+		node = calloc(1, sizeof *node);
+		if (node == NULL)
+			return -ENOMEM;
+		node->field = strdup(get_default_domain());
+		if (node->field == NULL)
+			return -ENOMEM;
+		toupper_str(node->field);
+
+		TAILQ_INSERT_TAIL(&local_realms->fields, node, link);
+		local_realms->cnt++;
+	}
 
 	nfs4_methods = conf_get_list("Translation", "Method");
 	if (nfs4_methods) {
